==> org-lsst-ccs-subsystem-fcs-main-1.4.4-sources.jar: org/lsst/ccs/subsystems/fcs/drivers/CanOpenTruckMotor.java <==
/*
 * To change this template, choose Tools | Templates
 * and on the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs.drivers;

import org.lsst.ccs.subsystems.fcs.errors.CanOpenException;
import org.lsst.ccs.subsystems.fcs.singlefiltertest.SftTruckMotor;

/**
 * This represents the motor that moves an autochanger truck along its rail.
 * @author virieux
 */
public class CanOpenTruckMotor extends SftTruckMotor {
    
     /**
     * The Digital Input-output which controls the motor.
     */
    CanOpenDIO dio;
    
     /**
     * This is the name of the DIO in the groovy file which is used in initModule.
     * 
     */
    String dioName;
    
    /**
     * Number of the output on the DIO8 where the motor is plugged
     */
    int outputNumeroToStandby;
    int outputNumeroToStandback;
    


    public CanOpenDIO getDio() {
        return dio;
    }

    public void setDio(CanOpenDIO dio) {
        this.dio = dio;
    }

    public int getOutputNumeroToStandback() {
        return outputNumeroToStandback;
    }

    public void setOutputNumeroToStandback(int outputNumeroToStandback) {
        this.outputNumeroToStandback = outputNumeroToStandback;
    }

    public int getOutputNumeroToStandby() {
        return outputNumeroToStandby;
    }

    public void setOutputNumeroToStandby(int outputNumeroToStandby) {
        this.outputNumeroToStandby = outputNumeroToStandby;
    }
    
    @Override
    public void initModule() {
        this.dio = (CanOpenDIO) this.getModule(dioName);
    }

    @Override
    public String moveToStandback() throws CanOpenException { 
        this.setMovingToStandback(true);
        return dio.tcpProxy.writeSDO(dio.nodeID, "6200", "1", "1", "1");

    }

    @Override
    public String moveToStandby() throws CanOpenException {
        this.setMovingToStandby(true);
        return dio.tcpProxy.writeSDO(dio.nodeID, "6200", "1", "1", "2");
    }

    @Override
    public String off() throws CanOpenException {
        this.setMovingToStandback(false);
        this.setMovingToStandby(false);
        return dio.tcpProxy.writeSDO(dio.nodeID, "6200", "1", "1", "0");
    }
    
    public String toString() {
        return super.toString();
    }
    
    

    
}

==> org-lsst-ccs-subsystem-fcs-main-2.0.1.1-sources.jar: org/lsst/ccs/subsystems/fcs/drivers/CanOpenTruckMotor.java <==
/*
 * To change this template, choose Tools | Templates
 * and on the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs.drivers;

import org.lsst.ccs.subsystems.fcs.errors.CanOpenException;
import org.lsst.ccs.subsystems.fcs.singlefiltertest.SftTruckMotor;

/**
 * This represents the motor that moves an autochanger truck along its rail in 
 * the single-filter-test test bench.
 * @author virieux
 */
public class CanOpenTruckMotor extends SftTruckMotor {
    
     /**
     * The Digital Input-output which controls the motor.
     */
    CanOpenDIO dio;
    
     /**
     * This is the name of the DIO in the groovy file which is used in initModule.
     * 
     */
    String dioName;
    
    /**
     * Number of the output on the DIO8 where the motor is plugged
     */
    int outputNumeroToStandby;
    int outputNumeroToStandback;
    


    public CanOpenDIO getDio() {
        return dio;
    }

    public void setDio(CanOpenDIO dio) {
        this.dio = dio;
    }

    public int getOutputNumeroToStandback() {
        return outputNumeroToStandback;
    }

    public void setOutputNumeroToStandback(int outputNumeroToStandback) {
        this.outputNumeroToStandback = outputNumeroToStandback;
    }

    public int getOutputNumeroToStandby() {
        return outputNumeroToStandby;
    }

    public void setOutputNumeroToStandby(int outputNumeroToStandby) {
        this.outputNumeroToStandby = outputNumeroToStandby;
    }
    
    @Override
    public void initModule() {
        this.dio = (CanOpenDIO) this.getModule(dioName);
    }

    @Override
    public String moveToStandback() throws CanOpenException { 
        this.setMovingToStandback(true);
        return dio.tcpProxy.writeSDO(dio.nodeID, "6200", "1", "1", "1");

    }

    @Override
    public String moveToStandby() throws CanOpenException {
        this.setMovingToStandby(true);
        return dio.tcpProxy.writeSDO(dio.nodeID, "6200", "1", "1", "2");
    }

    @Override
    public String off() throws CanOpenException {
        this.setMovingToStandback(false);
        this.setMovingToStandby(false);
        return dio.tcpProxy.writeSDO(dio.nodeID, "6200", "1", "1", "0");
    }
    
    public String toString() {
        return super.toString();
    }
    
    

    
}
